==> payara-embedded-all-4.1.1.171.1-sources.jar: fish/payara/notification/snmp/SnmpNotifierConfiguration.java <==
/*
 *
 * Copyright (c) 2016 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.notification.snmp;

import fish.payara.nucleus.notification.configuration.NotifierConfiguration;
import fish.payara.nucleus.notification.configuration.NotifierConfigurationType;
import fish.payara.nucleus.notification.configuration.NotifierType;
import org.jvnet.hk2.config.Attribute;
import org.jvnet.hk2.config.Configured;

import java.beans.PropertyVetoException;

/**
 * Configuration class with the aim to configure SNMP notification specific parameters.
 * This configuration is only being used by notification services.
 *
 * @author mertcaliskan
 */
@Configured
@NotifierConfigurationType(type = NotifierType.SNMP)
public interface SnmpNotifierConfiguration extends NotifierConfiguration {

    @Attribute(defaultValue = "public")
    String getCommunity();
    void setCommunity(String value) throws PropertyVetoException;

    // SNMP Trap for sysLocation
    @Attribute(defaultValue = ".1.3.6.1.2.1.1.8")
    String getOid();
    void setOid(String value) throws PropertyVetoException;

    @Attribute(defaultValue = "v2c")
    String getVersion();
    void setVersion(String value) throws PropertyVetoException;

    @Attribute(required = true)
    String getHost();
    void setHost(String value) throws PropertyVetoException;

    @Attribute(defaultValue = "162")
    Integer getPort();
    void setPort(String value) throws PropertyVetoException;
}

==> payara-embedded-all-5.2020.4-sources.jar: fish/payara/notification/snmp/SnmpNotifierConfiguration.java <==
/*
 *
 * Copyright (c) 2016 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.notification.snmp;

import fish.payara.nucleus.notification.configuration.NotifierConfiguration;
import fish.payara.nucleus.notification.configuration.NotifierConfigurationType;
import fish.payara.nucleus.notification.configuration.NotifierType;
import org.jvnet.hk2.config.Attribute;
import org.jvnet.hk2.config.Configured;

import java.beans.PropertyVetoException;

/**
 * Configuration class with the aim to configure SNMP notification specific parameters.
 * This configuration is only being used by notification services.
 *
 * @author mertcaliskan
 */
@Configured
@NotifierConfigurationType(type = NotifierType.SNMP)
public interface SnmpNotifierConfiguration extends NotifierConfiguration {

    @Attribute(defaultValue = "public")
    String getCommunity();
    void setCommunity(String value) throws PropertyVetoException;

    // SNMP Trap for sysLocation
    @Attribute(defaultValue = ".1.3.6.1.2.1.1.8")
    String getOid();
    void setOid(String value) throws PropertyVetoException;

    @Attribute(defaultValue = "v2c")
    String getVersion();
    void setVersion(String value) throws PropertyVetoException;

    @Attribute(required = true)
    String getHost();
    void setHost(String value) throws PropertyVetoException;

    @Attribute(defaultValue = "162", dataType = Integer.class)
    String getPort();
    void setPort(String value) throws PropertyVetoException;
}
